import os
import argparse
import xarray as xr

from DHDL import vertical_cross_section as vcs
from DHDL import subprogs
from DHDL import subprogs_xarray
from DDRW import draw_vertical_cross_section_1FIG as dvcs

####################
# developer shimizu shingo, NIED
##############################
# draw single vertical cross section 

def main():

    ## control for command line argument ##########################
    parser = argparse.ArgumentParser(description='draw netcdf')
    parser.add_argument('arg1',help='input file setting')
    parser.add_argument('arg2',help='variable setting')
    parser.add_argument('-t','--timenum',help='time slide from initial time')
    parser.add_argument('-T','--TIME',help='YYYY-M2-D2_H2:M2:S2(UTC)')
    parser.add_argument('-z','--levelnum',help='level number to be drawn')
    parser.add_argument('-Z','--LEV',help='level (m) to be drawn')
    parser.add_argument('-O','--OUTFIG',help='output file name')
    parser.add_argument('-W','--WIND',help='opt for wind draw 0:vector 1:barb')
    parser.add_argument('-WT','--WINDTHIN',\
                        help='data thinning out for vector, set mabiki factor')
    parser.add_argument('-CT','--ColorType',\
                        help='To use preset colormap, select colortype')
    parser.add_argument('-AR','--AutoRange',help='1: Manually set color range')
    parser.add_argument('-X0V','--X0_VCS',help='start lon for vcross section')
    parser.add_argument('-Y0V','--Y0_VCS',help='start lat for vcross section')
    parser.add_argument('-L0V','--L0_VCS',help='length(km) for vcross section')
    parser.add_argument('-A0V','--A0_VCS',\
                        help='deg anti-clockwise from east for vcross section')

    args = parser.parse_args()

    slon_ver = float(args.X0_VCS)
    slat_ver = float(args.Y0_VCS)
    len_ver  = float(args.L0_VCS)
    theta    = float(args.A0_VCS)

    need_vertical_interp = "NO"
    
    ####################################################################
    infile = args.arg1
    if not os.path.exists(infile):
        print ("infile does not exist \n",infile)
        exit(1)
        
    #open NETCDF as XARRAY
    data     = xr.open_dataset(infile)
    
    # get variable name
    varname  = args.arg2 
    
    #############################################################
    # check if the variable is included in NETCDF 
    subprogs.check_variable(data,varname,args)
    #############################################################

    #############################################################
    # check the dimension name    
    dimnameT,dimnameZ,dimnameY,dimnameX =subprogs.set_dim_name(data)
    #############################################################

    #############################################################
    # get lon and lat for vertical cross section
    dlon = subprogs.lon_per1km(data["LAT"].values)
    elon_ver,elat_ver = vcs.change_input_ver_cross(slon_ver,slat_ver,\
                                                   len_ver,theta,dlon)

    vert_info = [slon_ver,slat_ver,elon_ver,elat_ver,dlon,theta]
    #############################################################
    # check vertical cross section within domain
    vcs.check_domain(vert_info,data)
    #############################################################

    ### MAKE VERTICAL CROSS SECTION ##########
    if args.WIND is not None:
        Z1D,VER,TTT,colormap,clevels,UVALONG,WVER,scaleUV,maxUV =\
        vcs.make_vcross_sec(vert_info,data,varname,args,need_vertical_interp)
    else:
        Z1D,VER,TTT,colormap,clevels=\
        vcs.make_vcross_sec(vert_info,data,varname,args,need_vertical_interp)
    
    #################################################################
    # description for figure is saved as "figure title" 
    dimnameT,dimnameZ,dimnameY,dimnameX =subprogs.set_dim_name(data)
    TTT2 = str(TTT).split('.')[0]
    FigTitle= os.path.basename(infile) + " \n"
    FigTitle= FigTitle +  "var= " + varname + "(" + str(data[varname].units) \
        + ") " +  " time= " + TTT2 
    ################################################################

    ### draw vertical cross section ####
    draw_top    = 0.0 # draw_top == draw_bottom : no limilation
    draw_bottom = 0.0 # when draw_top>draw_bottom: draw the vertical range

    # if draw_top< draw_bottom, set_extent will skip (whole domain draw)
    if args.WIND is not None:
        dvcs.draw_vertical_cross_section_1FIG(VER,FigTitle,colormap,\
                                              clevels,args,\
                                              draw_top,draw_bottom,\
                                              UVALONG,WVER,maxUV,scaleUV)
    else:
        dvcs.draw_vertical_cross_section_1FIG(VER,FigTitle,colormap,\
                                              clevels,args,\
                                              draw_top,draw_bottom)
    
if __name__ == "__main__":
    main()
